{ config, lib, modulesPath, pkgs, ... }:

{
  imports = [
    (modulesPath + "/installer/scan/not-detected.nix")
  ];

  boot = {
    kernelModules = [ "kvm-intel" ];
    extraModulePackages = [ ];
    loader.grub.device = "/dev/disk/by-id/ata-INTEL_SSDSC2KB480G7_PHYS749202D6480BGN";
    initrd = {
      availableKernelModules = [ "aesni_intel" "ahci" "ehci_pci" "rtsx_pci_sdmmc" "sd_mod" "usb_storage" "usbhid" "xhci_pci" ];
      kernelModules = [ "dm-snapshot" ];
      luks.devices = {
        root = {
          name = "root";
          device = "/dev/disk/by-uuid/f3a2fa57-581b-4e95-9a45-d61cda9edc54";
          preLVM = true;
          allowDiscards = true;
        };
      };
    };
  };

  fileSystems = {
    "/" = {
      device = "/dev/disk/by-uuid/c3ab2182-18b3-4cc6-a5b3-3fef32222aef";
      fsType = "btrfs";
      options = [ "discard=async" "noatime" "compress=zstd" ];
    };

    "/boot" = {
      device = "/dev/disk/by-uuid/da2e90cc-1e0c-4691-8807-5d2f4858df6e";
      fsType = "ext2";
    };
  };

  swapDevices = [
    { device = "/dev/disk/by-uuid/b9ad2d56-fee0-49df-98c1-00d93d991b9f"; }
  ];

  powerManagement.cpuFreqGovernor = lib.mkDefault "performance";

  # Most of the time I want to use both screens at the same time and suspend it
  # regularily by closing the lid
  services.logind.lidSwitchDocked = config.services.logind.lidSwitch;

  hardware.opengl.extraPackages = with pkgs; [
    beignet # OpenCL for old intel GPU
  ];
}
