final: prev:
let
  inherit (prev) callPackage;
in
{
  bwrap-helper = callPackage ./bwrap-helper { };

  osu-lazer = callPackage ./osu-lazer { inherit (prev) osu-lazer; };
  osu-lazer-sandbox = callPackage ./osu-lazer-sandbox { };

  wordclock-dimmer = prev.python3Packages.callPackage ./wordclock-dimmer { };

  sbruder = prev.recurseIntoAttrs {
    contact = callPackage ./contact-page { };
    imprint = callPackage ./imprint { };
  };

  # adapted nixpkgs upstream but changed to buildGoModule and updated to
  # version that works in my setup
  prometheus-fritzbox-exporter = callPackage ./prometheus-fritzbox-exporter { };

  # TODO: Remove when pavucontrol > 4.0 is released
  pavucontrol = prev.pavucontrol.overrideAttrs (o: o // {
    patches = [
      # This fixes context menus on wayland
      # Bug report: https://gitlab.freedesktop.org/pulseaudio/pavucontrol/-/issues/63
      # Merge Request: https://gitlab.freedesktop.org/pulseaudio/pavucontrol/-/merge_requests/20
      (prev.fetchpatch {
        url = "https://gitlab.freedesktop.org/pulseaudio/pavucontrol/-/commit/ae278b8643cf1089f66df18713c8154208d9a505.patch";
        sha256 = "066vhxjz6gmi2sp2n4pa1cdsxjnq6yml5js094g5n7ld34p84dpj";
      })
    ];
  });

  # adapted from https://github.com/NixOS/nixpkgs/pull/85790
  # TODO: Remove when memtest86+ ≥ 5.31b is in nixpkgs
  memtest86plus = prev.memtest86plus.overrideAttrs (o: o // rec {
    version = "5.31b";

    src = prev.fetchurl {
      url = "https://www.memtest.org/download/${version}/memtest86+-${version}.tar.gz";
      sha256 = "028zrch87ggajlb5xx1c2ab85ggl9qldpibf45735sy0haqzyiki";
    };

    NIX_CFLAGS_COMPILE = null;

    buildFlags = [ ];

    doCheck = prev.stdenv.isi686;
    checkTarget = "run_self_test";
  });

  # TODO: remove once new version (> 0.3.0) is released and in nixpkgs
  nar-serve = prev.nar-serve.overrideAttrs (o: o // {
    version = "unstable-2021-04-08";

    src = prev.fetchFromGitHub {
      owner = "numtide";
      repo = "nar-serve";
      rev = "4243b0efa41910dfa4be8b9936ae460699d3f8f0";
      sha256 = "0mjs3yilf5rixm67wk4h4jji54dsc0w3vfxd561pvfbxplbmgh3c";
    };
  });

  # TODO: remove when flakes support is in nix stable
  nix-direnv = prev.nix-direnv.override {
    enableFlakes = true;
  };
}
